<?php

/**
 * SearchAPI processor.
 */
class purl_search_api implements purl_processor {

  public function method() {
    return 'search_api';
  }

  public function admin_form(&$form, $id) {
    // Note that while this form element's key includes the method ("pair"),
    // it will eventually save to the variable purl_method_[id]_key. See
    // element validator for how this occurs.
    $options = $this->condition_values();
    $form['purl_searchapi'] = array(
      '#type' => 'fieldset',
    );
    $form['purl_searchapi']["purl_method_search_api_key"] = array(
      '#title' => t('SearchAPI Setting'),
      '#type' => 'checkboxes',
      '#options' => $options,
      '#size' => 12,
      '#default_value' => variable_get("purl_method_search_api_key", array()),
    );

  }

  /**
   * Detect a default value for in the GET request, ignore elements drupal uses
   * already.
   */
  public function detect($q) {
    $f = drupal_get_query_parameters($_GET, array('q', 'sort', 'order', 'page', 'pass'));
      if (isset($f['f'])) {
        $new = array (
          'f' => $f['f'],
        );
        $query = drupal_http_build_query($new);
        return $query;
    }
    return "";
  }

  public function description() {
    return t('Choose a querystring. May contain only lowercase letters, numbers, dashes and underscores. e.g. "my-value"');
  }

  /**
   * Tear apart the path and iterate thought it looking for valid values.
   */
  public function parse($valid_values, $qs) {

    $elements = array();
    parse_str($qs, $elements);

    $parsed = array();
    foreach ($elements as $k => $v) {
    	if (isset($valid_values[$k])) {
        $parsed[$k] = $valid_values[$k];
        $parsed[$k]['id'] = $v;
    	}
    }
    return purl_path_elements($this, $parsed);
  }

  /**
   * No need to do nothing at all.
   */
  public function adjust(&$value, $item, &$q) {
      return;
  }

  /**
   * Removes specific modifier from a query string.
   *
   * @param $qs
   *   The current querystring.
   * @param $element
   *   a purl_path_element object
   * @return querystring with the modifier removed.
   */
  function remove($value, $element) {
    $qs = array();
    parse_str($value, $qs);
    unset($qs[$element->id]);
    return drupal_query_string_encode($qs);
  }

  /**
   *  Adds all f[] parameters to the selected views
   */
  public function rewrite(&$path, &$options, $element) {
    if (isset($options['attributes']['class'])) {
      if (in_array('purl_search_api_noreset', $options['attributes']['class'])) {
        if (!_purl_skip($element, $options)) {
          $options['query'][$element->value] = $element->id;
        }
      }
    }
  }

  /**
   *
   * @param string $path
   * The current path
   * @return boolean
   * True if $path is pointing to one of the selected views
   */
  function isselectedview($path) {
    $q = $_GET['q'];
    $result = FALSE;
    $views = variable_get("purl_method_search_api_key", '');
    foreach ($views as $option => $name) {
      if ($name) {
        $view_display = explode(":", $name);
        $viewname = $view_display[0];
        $displayname = isset($view_display[1]) ? $view_display[1] : 'default';
        $view = views_get_view($viewname);
        $display = $view->display[$displayname];
        $mypath = $display->display_options['path'];
        if (isset($mypath) && ($path == $mypath) && ($mypath != $q)) {
          $result = TRUE;
        }
      }
    }
    return $result;
  }

  /**
   * Generate a list of database and module provided views.
   * Ripped from context_condition_views.inc
   */
  function condition_values() {
    $enabled_views = array();

    $views = views_get_all_views();
    ksort($views);

    foreach ($views as $view) {
      if (!isset($views[$view->name]->disabled) || !$views[$view->name]->disabled) {
        $enabled_views[$view->name] = check_plain($view->name);

        // Provide more granular options for each page display
        $displays = array();
        foreach ($view->display as $id => $display) {
          if ($display->display_plugin == 'page') {
            $displays[$view->name . ":" . $id] = check_plain("-- {$display->display_title}");
          }
        }
        $enabled_views += $displays;
      }
    }
    return $enabled_views;
  }
}
